@@ -5,7 +5,7 @@
 require_once dirname(__FILE__) . '/Base.php';
 
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @category   Horde
@@ -86,9 +86,9 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
      */
     public function testGc()
     {
-        $probability = ini_get('session.gc_probability');
-        $divisor     = ini_get('session.gc_divisor');
-        $maxlifetime = ini_get('session.gc_maxlifetime');
+        $this->probability = ini_get('session.gc_probability');
+        $this->divisor     = ini_get('session.gc_divisor');
+        $this->maxlifetime = ini_get('session.gc_maxlifetime');
         ini_set('session.gc_probability', 100);
         ini_set('session.gc_divisor', 1);
         ini_set('session.gc_maxlifetime', -1);
@@ -96,9 +96,6 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
         @session_start();
         $this->assertEquals(array(),
                             self::$handler->getSessionIDs());
-        ini_set('session.gc_probability', $probability);
-        ini_set('session.gc_divisor', $divisor);
-        ini_set('session.gc_maxlifetime', $maxlifetime);
     }
 
     public static function setUpBeforeClass()
@@ -108,6 +105,15 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
         self::$handler = new Horde_SessionHandler_Storage_Builtin(array('path' => self::$dir));
     }
 
+    public function tearDown()
+    {
+        if (isset($this->probability)) {
+            ini_set('session.gc_probability', $this->probability);
+            ini_set('session.gc_divisor', $this->divisor);
+            ini_set('session.gc_maxlifetime', $this->maxlifetime);
+        }
+    }
+
     public static function tearDownAfterClass()
     {
         parent::tearDownAfterClass();
