@@ -5,7 +5,7 @@
 require_once dirname(__FILE__) . '/Base.php';
 
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @category   Horde
@@ -15,7 +15,7 @@ require_once dirname(__FILE__) . '/Base.php';
  */
 class Horde_SessionHandler_Storage_StackTest extends Horde_SessionHandler_Storage_Base
 {
-    static public $reason;
+    public static $reason;
 
     public function testWrite()
     {
